LogFlags

Struct LogFlags 

pub struct LogFlags { /* private fields */ }

Implementations

Source

impl LogFlags

pub const JOINT_MOTOR_TORQUES: LogFlags

pub const JOINT_USER_TORQUES: LogFlags

pub const JOINT_TORQUES: LogFlags

pub const fn empty() -> LogFlags

Returns an empty set of flags

pub const fn all() -> LogFlags

Returns the set containing all flags.

pub const fn bits(&self) -> i32

Returns the raw value of the flags currently stored.

pub fn from_bits(bits: i32) -> Option<LogFlags>

Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.

pub const fn from_bits_truncate(bits: i32) -> LogFlags

Convert from underlying bit representation, dropping any bits that do not correspond to flags.

pub const unsafe fn from_bits_unchecked(bits: i32) -> LogFlags

Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).

pub const fn is_empty(&self) -> bool

Returns true if no flags are currently stored.

pub const fn is_all(&self) -> bool

Returns true if all flags are currently set.

pub const fn intersects(&self, other: LogFlags) -> bool

Returns true if there are flags common to both self and other.

pub const fn contains(&self, other: LogFlags) -> bool

Returns true all of the flags in other are contained within self.

pub fn insert(&mut self, other: LogFlags)

Inserts the specified flags in-place.

pub fn remove(&mut self, other: LogFlags)

Removes the specified flags in-place.

pub fn toggle(&mut self, other: LogFlags)

Toggles the specified flags in-place.

pub fn set(&mut self, other: LogFlags, value: bool)

Inserts or removes the specified flags depending on the passed value.